==> undock-0.4.0.tar.gz: undock-0.4.0/README.md <==
<p align="center"><a href="https://github.com/crazy-max/undock" target="_blank"><img height="128" src="https://raw.githubusercontent.com/crazy-max/undock/master/.github/undock.png"></a></p>

<p align="center">
  <a href="https://crazymax.dev/undock/"><img src="https://img.shields.io/badge/doc-mkdocs-02a6f2?style=flat-square&logo=read-the-docs" alt="Documentation"></a>
  <a href="https://github.com/crazy-max/undock/releases/latest"><img src="https://img.shields.io/github/release/crazy-max/undock.svg?style=flat-square" alt="GitHub release"></a>
  <a href="https://github.com/crazy-max/undock/releases/latest"><img src="https://img.shields.io/github/downloads/crazy-max/undock/total.svg?style=flat-square" alt="Total downloads"></a>
  <a href="https://github.com/crazy-max/undock/actions?workflow=build"><img src="https://img.shields.io/github/actions/workflow/status/crazy-max/undock/build.yml?branch=main&label=build&logo=github&style=flat-square" alt="Build Status"></a>
  <a href="https://hub.docker.com/r/crazymax/undock/"><img src="https://img.shields.io/docker/stars/crazymax/undock.svg?style=flat-square&logo=docker" alt="Docker Stars"></a>
  <a href="https://hub.docker.com/r/crazymax/undock/"><img src="https://img.shields.io/docker/pulls/crazymax/undock.svg?style=flat-square&logo=docker" alt="Docker Pulls"></a>
  <br /><a href="https://goreportcard.com/report/github.com/crazy-max/undock"><img src="https://goreportcard.com/badge/github.com/crazy-max/undock?style=flat-square" alt="Go Report"></a>
  <a href="https://codecov.io/gh/crazy-max/undock"><img src="https://img.shields.io/codecov/c/github/crazy-max/undock?logo=codecov&style=flat-square" alt="Codecov"></a>
  <a href="https://github.com/sponsors/crazy-max"><img src="https://img.shields.io/badge/sponsor-crazy--max-181717.svg?logo=github&style=flat-square" alt="Become a sponsor"></a>
  <a href="https://www.paypal.me/crazyws"><img src="https://img.shields.io/badge/donate-paypal-00457c.svg?logo=paypal&style=flat-square" alt="Donate Paypal"></a>
</p>

## About

**Undock** is a CLI application that allows you to extract contents of a
container image in a local folder. This can be useful if you use a registry
to store artifacts in a scratch image, and you want to extract them on your
local machine with a single command.

## Features

* Many source support (docker, archive, store, oci, tar)
* Can extract multi-platform images
* Include a subset of files/dirs
* Cache support

## Documentation

Documentation can be found at https://crazymax.dev/undock/

## Contributing

Want to contribute? Awesome! The most basic way to show your support is to star the project, or to raise issues. If
you want to open a pull request, please read the [contributing guidelines](.github/CONTRIBUTING.md).

You can also support this project by [**becoming a sponsor on GitHub**](https://github.com/sponsors/crazy-max) or by
making a [Paypal donation](https://www.paypal.me/crazyws) to ensure this journey continues indefinitely!

Thanks again for your support, it is much appreciated! :pray:

## License

MIT. See `LICENSE` for more details.<br/>
Icon credit to [DinosoftLabs](https://dinosoftlab.com/).

==> undock-0.7.0.tar.gz: undock-0.7.0/README.md <==
<p align="center"><a href="https://github.com/crazy-max/undock" target="_blank"><img height="128" src="https://raw.githubusercontent.com/crazy-max/undock/master/.github/undock.png"></a></p>

<p align="center">
  <a href="https://crazymax.dev/undock/"><img src="https://img.shields.io/badge/doc-mkdocs-02a6f2?style=flat-square&logo=read-the-docs" alt="Documentation"></a>
  <a href="https://github.com/crazy-max/undock/releases/latest"><img src="https://img.shields.io/github/release/crazy-max/undock.svg?style=flat-square" alt="GitHub release"></a>
  <a href="https://github.com/crazy-max/undock/releases/latest"><img src="https://img.shields.io/github/downloads/crazy-max/undock/total.svg?style=flat-square" alt="Total downloads"></a>
  <a href="https://github.com/crazy-max/undock/actions?workflow=build"><img src="https://img.shields.io/github/actions/workflow/status/crazy-max/undock/build.yml?branch=main&label=build&logo=github&style=flat-square" alt="Build Status"></a>
  <a href="https://hub.docker.com/r/crazymax/undock/"><img src="https://img.shields.io/docker/stars/crazymax/undock.svg?style=flat-square&logo=docker" alt="Docker Stars"></a>
  <a href="https://hub.docker.com/r/crazymax/undock/"><img src="https://img.shields.io/docker/pulls/crazymax/undock.svg?style=flat-square&logo=docker" alt="Docker Pulls"></a>
  <br /><a href="https://goreportcard.com/report/github.com/crazy-max/undock"><img src="https://goreportcard.com/badge/github.com/crazy-max/undock?style=flat-square" alt="Go Report"></a>
  <a href="https://codecov.io/gh/crazy-max/undock"><img src="https://img.shields.io/codecov/c/github/crazy-max/undock?logo=codecov&style=flat-square" alt="Codecov"></a>
  <a href="https://github.com/sponsors/crazy-max"><img src="https://img.shields.io/badge/sponsor-crazy--max-181717.svg?logo=github&style=flat-square" alt="Become a sponsor"></a>
  <a href="https://www.paypal.me/crazyws"><img src="https://img.shields.io/badge/donate-paypal-00457c.svg?logo=paypal&style=flat-square" alt="Donate Paypal"></a>
</p>

## About

**Undock** is a CLI application that allows you to extract contents of a
container image in a local folder. This can be useful if you use a registry
to store artifacts in a scratch image, and you want to extract them on your
local machine with a single command.

## Features

* Many source support (docker, archive, store, oci, tar)
* Can extract multi-platform images
* Include a subset of files/dirs
* Cache support

## Documentation

Documentation can be found at https://crazymax.dev/undock/

## Contributing

Want to contribute? Awesome! The most basic way to show your support is to star
the project, or to raise issues. You can also support this project by [**becoming a sponsor on GitHub**](https://github.com/sponsors/crazy-max)
or by making a [PayPal donation](https://www.paypal.me/crazyws) to ensure this
journey continues indefinitely!

Thanks again for your support, it is much appreciated! :pray:

## License

MIT. See `LICENSE` for more details.<br/>
Icon credit to [DinosoftLabs](https://dinosoftlab.com/).
